pyxmpp.xmlextra._PythonReader

Package pyxmpp :: Module xmlextra :: Class _PythonReader |
[hide private]

# Class _PythonReader

source code

Python-only stream reader.

Instance Methods | [hide private]
__init__(self, handler) Initialize the reader. | source code
feed(self, data) Feed the parser with a chunk of data. | source code

Method Details | [hide private]

### __init__(self, handler) (Constructor) | source code
Initialize the reader. Parameters: `handler` (StreamHandler) - Object to handle stream start, end and stanzas.

### feed(self, data) | source code
Feed the parser with a chunk of data. Apropriate methods of `self.handler` will be called whenever something interesting is found. Parameters: `data` (`str`) - the chunk of data to parse.